@@ -1,3 +1,3 @@
 from flash.vision.classification import ImageClassificationData, ImageClassifier
-from flash.vision.detection import ImageDetector
+from flash.vision.detection import ObjectDetectionData, ObjectDetector
 from flash.vision.embedding import ImageEmbedder
